@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
-from authomatic.exceptions import SessionError, \
-    CredentialsError, RequestElementsError
+
 from xml.etree import ElementTree
 import Cookie
 import collections
@@ -18,6 +17,8 @@ import time
 import urllib
 import urlparse
 
+from authomatic.exceptions import SessionError, CredentialsError, RequestElementsError
+
 # Taken from anyjson.py
 try:
     import simplejson as json
@@ -919,9 +920,7 @@ class LoginResult(ReprMixin):
         """
         
         custom_callback = """
-        if (typeof window.opener.{cb} === "function") {{
-            window.opener.{cb}(result, closer);
-        }}
+        try {{ window.opener.{cb}(result, closer); }} catch(e) {{}}
         """.format(cb=callback_name) if callback_name else ''
         
         # TODO: Move the window.close() to the opener
@@ -937,11 +936,7 @@ class LoginResult(ReprMixin):
             
             {custom_callback}
             
-            if (typeof window.opener.authomatic !== "undefined" && window.opener.authomatic !== null) {{
-                if (typeof window.opener.authomatic.loginComplete === "function") {{
-                    window.opener.authomatic.loginComplete(result, closer);
-                }}
-            }}
+            try {{ window.opener.authomatic.loginComplete(result, closer); }} catch(e) {{}}
         
         }})();
         
